pub async fn connect_reader_for_writer(
cfg: &DatabaseConfig,
writer: DatabaseConnection,
) -> Result<DbHandles>Expand description
Creates reader/writer handles for an existing writer connection without metrics.
pub async fn connect_reader_for_writer(
cfg: &DatabaseConfig,
writer: DatabaseConnection,
) -> Result<DbHandles>Creates reader/writer handles for an existing writer connection without metrics.