pub fn database_component(
db_handles: DbHandles,
) -> RuntimeComponentBundleRegistration<DatabaseRuntimeComponent>Expand description
Creates the database runtime component used by product entrypoints.
pub fn database_component(
db_handles: DbHandles,
) -> RuntimeComponentBundleRegistration<DatabaseRuntimeComponent>Creates the database runtime component used by product entrypoints.