pub struct ScheduledTaskDbStore { /* private fields */ }Expand description
SeaORM-backed scheduled task store.
Implementations
Sourceimpl ScheduledTaskDbStore
impl ScheduledTaskDbStore
Sourcepub const fn new(db: DatabaseConnection) -> Self
pub const fn new(db: DatabaseConnection) -> Self
Creates a scheduled task store from a SeaORM database connection.
Sourcepub async fn ensure_task(
&self,
entry: ScheduledTaskCatalogEntry<'_>,
) -> Result<Model>
pub async fn ensure_task( &self, entry: ScheduledTaskCatalogEntry<'_>, ) -> Result<Model>
Ensures one product scheduled task is present in the catalog.
Sourcepub async fn claim_due(
&self,
request: ScheduledTaskClaimRequest<'_>,
) -> Result<Option<ScheduledTaskClaim>>
pub async fn claim_due( &self, request: ScheduledTaskClaimRequest<'_>, ) -> Result<Option<ScheduledTaskClaim>>
Attempts to claim one due scheduled task firing.
Sourcepub async fn renew_claim(
&self,
renewal: ScheduledTaskClaimRenewal<'_>,
) -> Result<bool>
pub async fn renew_claim( &self, renewal: ScheduledTaskClaimRenewal<'_>, ) -> Result<bool>
Renews an owned claim while the task body is still running.
Sourcepub async fn complete_claim(
&self,
completion: ScheduledTaskCompletion,
) -> Result<bool>
pub async fn complete_claim( &self, completion: ScheduledTaskCompletion, ) -> Result<bool>
Completes a claimed firing and advances the next due timestamp.